@@ -2,7 +2,7 @@ package Test2::Tools::Basic;
 use strict;
 use warnings;
 
-our $VERSION = '0.000053';
+our $VERSION = '0.000056';
 
 use Carp qw/croak/;
 use Test2::API qw/context/;
@@ -78,7 +78,7 @@ sub plan {
     my $plan = shift;
     my $ctx = context();
 
-    if ($plan && $plan =~ m/\D/) {
+    if ($plan && $plan =~ m/[^0-9]/) {
         if ($plan eq 'tests') {
             $plan = shift;
         }
