@@ -2,7 +2,7 @@ package Test2::Tools::Compare;
 use strict;
 use warnings;
 
-our $VERSION = '0.000053';
+our $VERSION = '0.000056';
 
 use Carp qw/croak/;
 use Scalar::Util qw/reftype/;
@@ -583,7 +583,7 @@ your data. There are both 'strict' and 'relaxed' versions of the tools.
     # regex to approximate a field.
     like(
         $some_hash,
-        {a => 1, b => qr/\d+/},
+        {a => 1, b => qr/[0-9]+/},
         "'a' is 1, 'b' is an integer, we don't care about 'c'."
     );
 
@@ -656,7 +656,7 @@ provided and converted to a specification for you.
         $some_hash,
         hash {    # Note: the hash function is not exported by default
             field a => 1;
-            field b => match(qr/\d+/);    # Note: The match function is not exported by default
+            field b => match(qr/[0-9]+/);    # Note: The match function is not exported by default
             # Don't care about other fields.
         },
         "The hash comparison is not strict"
@@ -708,7 +708,7 @@ In this tool regexes will stringify the thing they are checking.
 
     like(
         $some_hash,
-        {a => 1, b => qr/\d+/},
+        {a => 1, b => qr/[0-9]+/},
         "'a' is 1, 'b' is an integer, we don't care about other fields"
     );
 
@@ -1036,7 +1036,7 @@ B<Note: None of these are exported by default. You need to request them.>
         item 'f';
 
         # Remove any REMAINING items that contain 0-9.
-        filter_items { grep {m/\D/} @_ };
+        filter_items { grep {!m/[0-9]/} @_ };
 
         # Set checks that apply to all items. Can be done multiple times, and
         # each call can define multiple checks, all will be run.
